<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="327"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Acquista versione ultimate per finanziare lo sviluppo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="412"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>File %1/%2, dimensione: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="646"/>
        <source>Copy list</source>
        <translation>Lista di copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="648"/>
        <source>Move list</source>
        <translation>Lista di spostamento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1076"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono trovati errori</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1077"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1078"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1080"/>
        <source>File Name, 0KB</source>
        <translation>Nome file, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1274"/>
        <location filename="../../interface.cpp" line="1286"/>
        <location filename="../../interface.cpp" line="1298"/>
        <source>Select a color</source>
        <translation>Selezionare colore</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1373"/>
        <location filename="../../interface.cpp" line="1377"/>
        <location filename="../../interface.cpp" line="1379"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% di %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Selezionare colore</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="35"/>
        <source>From:</source>
        <translation>Da:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="65"/>
        <source>To:</source>
        <translation>A:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="226"/>
        <source>&amp;More</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="246"/>
        <source>&amp;Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="260"/>
        <source>&amp;Skip</source>
        <translation>Salta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="271"/>
        <source>&amp;Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="118"/>
        <source>Close on transfer completion</source>
        <translation>Chiudi a trasferimento completato</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="286"/>
        <source>Limit copy speed to:</source>
        <translation>Limitare velocità di copia a:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="329"/>
        <source>Transfer list</source>
        <translation>Lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="352"/>
        <source>Move the selected items to the top</source>
        <translation>Metti elementi selezionati in cima</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="378"/>
        <source>Move up the selected items</source>
        <translation>Sposta elementi selezionati in sù</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="404"/>
        <source>Move down the selected items</source>
        <translation>Sposta elementi selezionati in giù</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="430"/>
        <source>Move the selected items to the bottom</source>
        <translation>Metti elementi selezionati in coda</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="456"/>
        <source>Add file/folder</source>
        <translation>Aggiungi file/cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="485"/>
        <source>Delete the selected items</source>
        <translation>Elimina elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="511"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="540"/>
        <source>Export the transfer list</source>
        <translation>Esporta lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="566"/>
        <source>Import the transfer list</source>
        <translation>Importa lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="621"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="628"/>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="663"/>
        <location filename="../../interface.ui" line="732"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="683"/>
        <source>Export the errors into transfer list</source>
        <translation>Esporta errori in lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="722"/>
        <source>Source</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="727"/>
        <source>Destination</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="741"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="778"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="787"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Move file(s)</source>
        <translation>Spostare file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Move folder</source>
        <translation>Spostare cartella/e</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Copy file(s)</source>
        <translation>Copiare file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Copy folder</source>
        <translation>Copiare cartella/e</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>Mostrare progressione duale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrare velocità come informazione principale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Funzionalità</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Avvio con bottone &quot;Avanzate&quot; premuto</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Alla chiusura riduci nell&apos;area di notifica</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>A fine copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitare velocità di copia a</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Avvia ridotto a icona</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Cliccare per modificare colore</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Salva posizione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualizzazione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Velocità in barra progresso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Colore progressione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Mostra percentuale di progresso nel titolo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Sempre in primo piano</translation>
    </message>
</context>
</TS>
